<?php

/**
 * Copyright 2019 IQRF Tech s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
declare(strict_types = 1);

namespace Iqrf\Repository\Entities;

use JsonSerializable;

/**
 * IQRF Standard entity
 */
final class Standard implements JsonSerializable {

	/**
	 * @var int Standard ID
	 */
	private $id;

	/**
	 * @var string Standard name
	 */
	private $name;

	/**
	 * Constructor
	 * @param int $id Standard ID
	 * @param string $name Standard name
	 */
	public function __construct(int $id, string $name) {
		$this->id = $id;
		$this->name = $name;
	}

	/**
	 * Creates a new standard entity from an array
	 * @param array<string,mixed> $data JSON data in an array
	 * @return Standard Created standard entity
	 */
	public static function fromArray(array $data): self {
		return new static($data['standardID'], $data['name']);
	}

	/**
	 * Returns the standard ID
	 * @return int Standard ID
	 */
	public function getId(): int {
		return $this->id;
	}

	/**
	 * Returns the standard name
	 * @return string Standard name
	 */
	public function getName(): string {
		return $this->name;
	}

	/**
	 * Serializes the IQRF Standard entity into JSON
	 * @return array<string, int|string> JSON serialized IQRF Standard entity
	 */
	public function jsonSerialize(): array {
		return [
			'id' => $this->id,
			'name' => $this->name,
		];
	}

}
